@@ -2,7 +2,7 @@ package Parse::Taxonomy;
 use strict;
 use Carp;
 use Scalar::Util qw( reftype );
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 NAME
 
@@ -10,8 +10,8 @@ Parse::Taxonomy - Validate hierarchical data stored in CSV format
 
 =head1 VERSION
 
-This document refers to version 0.13 of Parse::Taxonomy.  This version was
-released September 19 2015.
+This document refers to version 0.14 of Parse::Taxonomy.  This version was
+released October 11 2015.
 
 =head1 SYNOPSIS
 
@@ -206,11 +206,11 @@ representing this tree would look like this:
 A B<taxonomy-by-adjacent-list> is one in which each record has a column with a
 unique identifier (B<id>) and another column holding the unique identifier of
 the record representing the next higher node in the hierarchy (B<parent_id>).
-The record must also a column which holds a datum that is unique among all
-records having the same parent node.
+The record must also have a column which holds a datum that is unique among
+all records having the same parent node.
 
-Let's make this clearer by rewriting the taxonomy-by-materialized-path above for Example 3
-as a taxonomy-by-adjacent-list.
+Let's make this clearer by rewriting the taxonomy-by-materialized-path above
+for Example 3 as a taxonomy-by-adjacent-list.
 
     "id","parent_id","name","nationality","gender","age","income","id_no"
     1,,"Alpha","","","","",""
@@ -244,8 +244,8 @@ value identical to the child's C<parent_id>.
 
     Via name:  Kappa    Epsilon Alpha
 
-We go from C<id 3> to its C<parent_id 2>, then to C<2>'s C<parent_id 1>.
-Putting C<name>s to this, we go from C<Kappa> to C<Epsilon> to C<Alpha>.
+We go from C<id 3> to its C<parent_id>, <2>, then to C<2>'s C<parent_id>, <1>.
+Putting names to this, we go from C<Kappa> to C<Epsilon> to C<Alpha>.
 
 Now, reverse the order of those C<name>s, throw a pipe delimiter before each
 of them and join them into a single string, and you get:
@@ -257,7 +257,7 @@ taxonomy-by-materialized-path displayed previously.
 
 With correct data, a given hierarchy of data can therefore be represented
 either by a taxonomy-by-materialized-path or by a taxonomy-by-adjacent-list.
-This permit us to describe these two taxonomies as B<equivalent> to each
+This permits us to describe these two taxonomies as B<equivalent> to each
 other.
 
 =head2 Taxonomy Validation
@@ -338,7 +338,7 @@ or through the web interface at L<http://rt.cpan.org>.
 James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'Parse::Taxonomy' or 'Parse-Taxonomy' in your subject line.
 
-Creation date:  May 24 2015.  Last modification date:  September 19 2015.
+Creation date:  May 24 2015.  Last modification date:  October 11 2015.
 
 Development repository: L<https://github.com/jkeenan/parse-taxonomy>
 
@@ -353,6 +353,9 @@ by Larry Leszczynski
 L<Trees in SQL: Nested Sets and Materialized Path|https://communities.bmc.com/docs/DOC-9902>
 by Vadim Tropashko
 
+L<DBIx-Tree|http://search.cpan.org/dist/DBIx-Tree/>, now maintained by Ron
+Savage.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
