@@ -6,7 +6,7 @@ use Text::CSV_XS;
 use Scalar::Util qw( reftype );
 use List::Util qw( max );
 use Cwd;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 use Parse::Taxonomy::Auxiliary qw(
     path_check_fields
     components_check_fields
@@ -23,14 +23,14 @@ Parse::Taxonomy::MaterializedPath - Validate a file for use as a path-based taxo
     # 'file' interface: reads a CSV file for you
 
     $source = "./t/data/alpha.csv";
-    $obj = Parse::Taxonomy::MaterializedPath->new( {
+    $self = Parse::Taxonomy::MaterializedPath->new( {
         file    => $source,
     } );
 
     # 'components' interface:  as if you've already read a
     # CSV file and now have Perl array references to header and data rows
 
-    $obj = Parse::Taxonomy::MaterializedPath->new( {
+    $self = Parse::Taxonomy::MaterializedPath->new( {
         components  => {
             fields          => $fields,
             data_records    => $data_records,
@@ -56,7 +56,7 @@ Single hash reference.  There are two possible interfaces: C<file> and C<compone
 =item 1 C<file> interface
 
     $source = "./t/data/alpha.csv";
-    $obj = Parse::Taxonomy::MaterializedPath->new( {
+    $self = Parse::Taxonomy::MaterializedPath->new( {
         file    => $source,
         path_col_idx    => 0,
         path_col_sep    => '|',
@@ -94,7 +94,7 @@ Text::CSV documentation, C<binary> is always set to a true value.
 
 =item 2 C<components> interface
 
-    $obj = Parse::Taxonomy::MaterializedPath->new( {
+    $self = Parse::Taxonomy::MaterializedPath->new( {
         components  => {
             fields          => $fields,
             data_records    => $data_records,
@@ -634,7 +634,7 @@ Identify the index position of a given field within the header row.
 
 =item * Arguments
 
-    $index = $obj->get_field_position('income');
+    $index = $self->get_field_position('income');
 
 Takes a single string holding the name of one of the fields (column names).
 
@@ -846,9 +846,9 @@ Transform a taxonomy-by-materialized-path into a taxonomy-by-adjacent-list.
 
 =item * Arguments
 
-    $adjacentified = $obj->adjacentify();
+    $adjacentified = $self->adjacentify();
 
-    $adjacentified = $obj->adjacentify( { serial => 500 } );
+    $adjacentified = $self->adjacentify( { serial => 500 } );
 
 Optional single hash reference.
 
@@ -885,43 +885,43 @@ sub adjacentify {
     my $drpc = $self->data_records_path_components();
 
     my $path_col_idx = $self->path_col_idx();
-    my %col2idx = map { $fields->[$_] => $_  } (0..$#{$fields});
     my %non_path_col2idx = map { $fields->[$_] => $_  }
         grep { $_ != $path_col_idx }
         (0..$#{$fields});
-    my %idx2col = map { $_ => $fields->[$_] } (0..$#{$fields});
-    my %non_path_idx2col = map { $_ => $fields->[$_] }
-        grep { $_ != $path_col_idx }
-        (0..$#{$fields});
 
     my @components_by_row =
         map { my $f = $_->[$path_col_idx]; my $c = $#{$f}; [ @{$f}[1..$c] ] }  @{$drpc};
     my $max_components = max( map { scalar(@{$_}) } @components_by_row);
     my $serial = $args->{serial} || 0;
     my @adjacentified = ();
-    my %depth_name_id = ();
+    my %paths_to_id;
     for my $depth (1..$max_components) {
         for (my $r = 0; $r <= $#components_by_row; $r++) {
             if (scalar(@{$components_by_row[$r]}) == $depth) {
                 my %rowdata = map { $_ => $drpc->[$r]->[$non_path_col2idx{$_}] }
                     keys %non_path_col2idx;
-                my $name = $drpc->[$r]->[$path_col_idx]->[$depth];
-                my $parent_of_name = $drpc->[$r]->[$path_col_idx]->[$depth-1];
-                my $parent_id = defined($depth_name_id{$depth-1}{$parent_of_name})
-                    ? $depth_name_id{$depth-1}{$parent_of_name}
-                    : '';
+                my @path_components = @{$drpc->[$r]->[$path_col_idx]};
+                my $name = $path_components[-1];
+                my $parent_of_name = join('|' =>
+                    @path_components[1 .. ($#path_components -1)]);
+
+                my $candidate_for_path = (length($parent_of_name))
+                    ? join('|' => $parent_of_name, $name)
+                    : $name;
+
                 my %rowhash = (
                     id => ++$serial,
-                    parent_id => $parent_id,
+                    parent_id => $paths_to_id{$parent_of_name}{id},
                     name => $name,
                     %rowdata,
                 );
-                $depth_name_id{$depth}{$name} = $rowhash{id};
+                $paths_to_id{$candidate_for_path}{id} = $rowhash{id};
+                $paths_to_id{$candidate_for_path}{parent_path} = $parent_of_name
+                    if (length($parent_of_name));
                 push @adjacentified, \%rowhash;
             }
         }
     }
-
     return \@adjacentified;
 }
 
@@ -935,7 +935,7 @@ Create a CSV-formatted file holding the data returned by C<adjacentify()>.
 
 =item * Arguments
 
-    $csv_file = $obj->write_adjacentified_to_csv( {
+    $csv_file = $self->write_adjacentified_to_csv( {
        adjacentified => $adjacentified,                   # output of adjacentify()
        csvfile => './t/data/taxonomy_out3.csv',
     } );
